@@ -4,7 +4,6 @@ import { Cronos } from "../idl";
 import { AuthorityGateway } from "./authority";
 import { ConfigGateway } from "./config";
 import { DaemonGateway } from "./daemon";
-import { FrameGateway } from "./frame";
 import { RevenueGateway } from "./revenue";
 import { TaskGateway } from "./task";
 import { TreasuryGateway } from "./treasury";
@@ -13,7 +12,6 @@ export class Account {
   public authority: AuthorityGateway;
   public config: ConfigGateway;
   public daemon: DaemonGateway;
-  public frame: FrameGateway;
   public revenue: RevenueGateway;
   public task: TaskGateway;
   public treasury: TreasuryGateway;
@@ -22,7 +20,6 @@ export class Account {
     this.authority = new AuthorityGateway(cronos, cronos.account.authority);
     this.config = new ConfigGateway(cronos, cronos.account.config);
     this.daemon = new DaemonGateway(cronos, cronos.account.daemon);
-    this.frame = new FrameGateway(cronos, cronos.account.frame);
     this.revenue = new RevenueGateway(cronos, cronos.account.revenue);
     this.task = new TaskGateway(cronos, cronos.account.task);
     this.treasury = new TreasuryGateway(cronos, cronos.account.treasury);
