@@ -1,5 +1,5 @@
 export type Cronos = {
-  "version": "0.0.1",
+  "version": "0.0.2",
   "name": "cronos",
   "instructions": [
     {
@@ -23,27 +23,6 @@ export type Cronos = {
         }
       ]
     },
-    {
-      "name": "configUpdateFrameInterval",
-      "accounts": [
-        {
-          "name": "admin",
-          "isMut": true,
-          "isSigner": true
-        },
-        {
-          "name": "config",
-          "isMut": true,
-          "isSigner": false
-        }
-      ],
-      "args": [
-        {
-          "name": "newFrameInterval",
-          "type": "u64"
-        }
-      ]
-    },
     {
       "name": "configUpdateProgramFee",
       "accounts": [
@@ -135,65 +114,6 @@ export type Cronos = {
         }
       ]
     },
-    {
-      "name": "frameCreate",
-      "accounts": [
-        {
-          "name": "authority",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "clock",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "config",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "frame",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "indexerProgram",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "list",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "payer",
-          "isMut": true,
-          "isSigner": true
-        },
-        {
-          "name": "systemProgram",
-          "isMut": false,
-          "isSigner": false
-        }
-      ],
-      "args": [
-        {
-          "name": "timestamp",
-          "type": "u64"
-        },
-        {
-          "name": "frameBump",
-          "type": "u8"
-        },
-        {
-          "name": "listBump",
-          "type": "u8"
-        }
-      ]
-    },
     {
       "name": "initialize",
       "accounts": [
@@ -314,41 +234,16 @@ export type Cronos = {
     {
       "name": "taskCreate",
       "accounts": [
-        {
-          "name": "authority",
-          "isMut": true,
-          "isSigner": false
-        },
         {
           "name": "daemon",
           "isMut": true,
           "isSigner": false
         },
-        {
-          "name": "frame",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "indexerProgram",
-          "isMut": false,
-          "isSigner": false
-        },
         {
           "name": "task",
           "isMut": true,
           "isSigner": false
         },
-        {
-          "name": "taskElement",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "taskList",
-          "isMut": true,
-          "isSigner": false
-        },
         {
           "name": "owner",
           "isMut": true,
@@ -380,11 +275,7 @@ export type Cronos = {
           "type": "u64"
         },
         {
-          "name": "taskBump",
-          "type": "u8"
-        },
-        {
-          "name": "taskElementBump",
+          "name": "bump",
           "type": "u8"
         }
       ]
@@ -428,11 +319,6 @@ export type Cronos = {
     {
       "name": "taskRepeat",
       "accounts": [
-        {
-          "name": "authority",
-          "isMut": true,
-          "isSigner": false
-        },
         {
           "name": "config",
           "isMut": false,
@@ -443,31 +329,11 @@ export type Cronos = {
           "isMut": true,
           "isSigner": false
         },
-        {
-          "name": "indexerProgram",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "nextFrame",
-          "isMut": false,
-          "isSigner": false
-        },
         {
           "name": "nextTask",
           "isMut": true,
           "isSigner": false
         },
-        {
-          "name": "nextTaskElement",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "nextTaskList",
-          "isMut": true,
-          "isSigner": false
-        },
         {
           "name": "prevTask",
           "isMut": true,
@@ -486,11 +352,7 @@ export type Cronos = {
       ],
       "args": [
         {
-          "name": "nextTaskBump",
-          "type": "u8"
-        },
-        {
-          "name": "nextTaskElementBump",
+          "name": "bump",
           "type": "u8"
         }
       ]
@@ -518,10 +380,6 @@ export type Cronos = {
             "name": "adminAuthority",
             "type": "publicKey"
           },
-          {
-            "name": "frameInterval",
-            "type": "u64"
-          },
           {
             "name": "programFee",
             "type": "u64"
@@ -557,22 +415,6 @@ export type Cronos = {
         ]
       }
     },
-    {
-      "name": "frame",
-      "type": {
-        "kind": "struct",
-        "fields": [
-          {
-            "name": "timestamp",
-            "type": "u64"
-          },
-          {
-            "name": "bump",
-            "type": "u8"
-          }
-        ]
-      }
-    },
     {
       "name": "revenue",
       "type": {
@@ -724,21 +566,26 @@ export type Cronos = {
     },
     {
       "code": 6001,
+      "name": "InvalidTimestamp",
+      "msg": "The provided timestamp is not a valid frame"
+    },
+    {
+      "code": 6002,
       "name": "TaskNotPending",
       "msg": "Task is not pending and may not executed"
     },
     {
-      "code": 6002,
+      "code": 6003,
       "name": "TaskNotRepeatable",
       "msg": "This task is not marked for repeat"
     },
     {
-      "code": 6003,
+      "code": 6004,
       "name": "TaskNotDue",
       "msg": "This task is not due and may not be executed yet"
     },
     {
-      "code": 6004,
+      "code": 6005,
       "name": "Unknown",
       "msg": "Unknown error"
     }
@@ -746,7 +593,7 @@ export type Cronos = {
 };
 
 export const IDL: Cronos = {
-  "version": "0.0.1",
+  "version": "0.0.2",
   "name": "cronos",
   "instructions": [
     {
@@ -770,27 +617,6 @@ export const IDL: Cronos = {
         }
       ]
     },
-    {
-      "name": "configUpdateFrameInterval",
-      "accounts": [
-        {
-          "name": "admin",
-          "isMut": true,
-          "isSigner": true
-        },
-        {
-          "name": "config",
-          "isMut": true,
-          "isSigner": false
-        }
-      ],
-      "args": [
-        {
-          "name": "newFrameInterval",
-          "type": "u64"
-        }
-      ]
-    },
     {
       "name": "configUpdateProgramFee",
       "accounts": [
@@ -882,65 +708,6 @@ export const IDL: Cronos = {
         }
       ]
     },
-    {
-      "name": "frameCreate",
-      "accounts": [
-        {
-          "name": "authority",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "clock",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "config",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "frame",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "indexerProgram",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "list",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "payer",
-          "isMut": true,
-          "isSigner": true
-        },
-        {
-          "name": "systemProgram",
-          "isMut": false,
-          "isSigner": false
-        }
-      ],
-      "args": [
-        {
-          "name": "timestamp",
-          "type": "u64"
-        },
-        {
-          "name": "frameBump",
-          "type": "u8"
-        },
-        {
-          "name": "listBump",
-          "type": "u8"
-        }
-      ]
-    },
     {
       "name": "initialize",
       "accounts": [
@@ -1061,41 +828,16 @@ export const IDL: Cronos = {
     {
       "name": "taskCreate",
       "accounts": [
-        {
-          "name": "authority",
-          "isMut": true,
-          "isSigner": false
-        },
         {
           "name": "daemon",
           "isMut": true,
           "isSigner": false
         },
-        {
-          "name": "frame",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "indexerProgram",
-          "isMut": false,
-          "isSigner": false
-        },
         {
           "name": "task",
           "isMut": true,
           "isSigner": false
         },
-        {
-          "name": "taskElement",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "taskList",
-          "isMut": true,
-          "isSigner": false
-        },
         {
           "name": "owner",
           "isMut": true,
@@ -1127,11 +869,7 @@ export const IDL: Cronos = {
           "type": "u64"
         },
         {
-          "name": "taskBump",
-          "type": "u8"
-        },
-        {
-          "name": "taskElementBump",
+          "name": "bump",
           "type": "u8"
         }
       ]
@@ -1175,11 +913,6 @@ export const IDL: Cronos = {
     {
       "name": "taskRepeat",
       "accounts": [
-        {
-          "name": "authority",
-          "isMut": true,
-          "isSigner": false
-        },
         {
           "name": "config",
           "isMut": false,
@@ -1190,31 +923,11 @@ export const IDL: Cronos = {
           "isMut": true,
           "isSigner": false
         },
-        {
-          "name": "indexerProgram",
-          "isMut": false,
-          "isSigner": false
-        },
-        {
-          "name": "nextFrame",
-          "isMut": false,
-          "isSigner": false
-        },
         {
           "name": "nextTask",
           "isMut": true,
           "isSigner": false
         },
-        {
-          "name": "nextTaskElement",
-          "isMut": true,
-          "isSigner": false
-        },
-        {
-          "name": "nextTaskList",
-          "isMut": true,
-          "isSigner": false
-        },
         {
           "name": "prevTask",
           "isMut": true,
@@ -1233,11 +946,7 @@ export const IDL: Cronos = {
       ],
       "args": [
         {
-          "name": "nextTaskBump",
-          "type": "u8"
-        },
-        {
-          "name": "nextTaskElementBump",
+          "name": "bump",
           "type": "u8"
         }
       ]
@@ -1265,10 +974,6 @@ export const IDL: Cronos = {
             "name": "adminAuthority",
             "type": "publicKey"
           },
-          {
-            "name": "frameInterval",
-            "type": "u64"
-          },
           {
             "name": "programFee",
             "type": "u64"
@@ -1304,22 +1009,6 @@ export const IDL: Cronos = {
         ]
       }
     },
-    {
-      "name": "frame",
-      "type": {
-        "kind": "struct",
-        "fields": [
-          {
-            "name": "timestamp",
-            "type": "u64"
-          },
-          {
-            "name": "bump",
-            "type": "u8"
-          }
-        ]
-      }
-    },
     {
       "name": "revenue",
       "type": {
@@ -1471,21 +1160,26 @@ export const IDL: Cronos = {
     },
     {
       "code": 6001,
+      "name": "InvalidTimestamp",
+      "msg": "The provided timestamp is not a valid frame"
+    },
+    {
+      "code": 6002,
       "name": "TaskNotPending",
       "msg": "Task is not pending and may not executed"
     },
     {
-      "code": 6002,
+      "code": 6003,
       "name": "TaskNotRepeatable",
       "msg": "This task is not marked for repeat"
     },
     {
-      "code": 6003,
+      "code": 6004,
       "name": "TaskNotDue",
       "msg": "This task is not due and may not be executed yet"
     },
     {
-      "code": 6004,
+      "code": 6005,
       "name": "Unknown",
       "msg": "Unknown error"
     }
