@@ -8,6 +8,8 @@ use {
 #[instruction(
     authority_bump: u8,
     config_bump: u8,
+    daemon_bump: u8,
+    fee_bump: u8,
     health_bump: u8,
     treasury_bump: u8,
 )]
@@ -30,6 +32,30 @@ pub struct Initialize<'info> {
     )]
     pub config: Account<'info, Config>,
 
+    #[account(
+        init,
+        seeds = [
+            SEED_DAEMON, 
+            authority.key().as_ref()
+        ],
+        bump = daemon_bump,
+        payer = signer,
+        space = 8 + size_of::<Daemon>(),
+    )]
+    pub daemon: Account<'info, Daemon>,
+
+    #[account(
+        init,
+        seeds = [
+            SEED_FEE, 
+            daemon.key().as_ref()
+        ],
+        bump = fee_bump,
+        payer = signer,
+        space = 8 + size_of::<Fee>(),
+    )]
+    pub fee: Account<'info, Fee>,
+
     #[account(
         init,
         seeds = [SEED_HEALTH],
@@ -39,6 +65,7 @@ pub struct Initialize<'info> {
     )]
     pub health: Account<'info, Health>,
 
+
     #[account(mut)]
     pub signer: Signer<'info>,
 
@@ -59,12 +86,16 @@ pub fn handler(
     ctx: Context<Initialize>,
     authority_bump: u8,
     config_bump: u8,
+    daemon_bump: u8,
+    fee_bump: u8,
     health_bump: u8,
     treasury_bump: u8,
 ) -> ProgramResult {
     // Get accounts.
     let authority = &mut ctx.accounts.authority;
     let config = &mut ctx.accounts.config;
+    let daemon = &mut ctx.accounts.daemon;
+    let fee = &mut ctx.accounts.fee;
     let health = &mut ctx.accounts.health;
     let signer = &ctx.accounts.signer;
     let treasury = &mut ctx.accounts.treasury;
@@ -72,6 +103,16 @@ pub fn handler(
     // Initialize authority account.
     authority.bump = authority_bump;
 
+    // Initialize daemon account.
+    daemon.owner = authority.key();
+    daemon.task_count = 0;
+    daemon.bump = daemon_bump;
+
+    // Initialize fee account.
+    fee.daemon = daemon.key();
+    fee.balance = 0;
+    fee.bump = fee_bump;
+
     // Initialize health account.
     health.real_time = 0;
     health.target_time = 0;
